Struct nvml_wrapper::bitmasks::device::ThrottleReasons
source · [−]pub struct ThrottleReasons { /* private fields */ }Expand description
Flags used to specify why a GPU is throttling.
Implementations
sourceimpl ThrottleReasons
impl ThrottleReasons
sourcepub const GPU_IDLE: Self = Self{bits: nvmlClocksThrottleReasonGpuIdle as u64,}
pub const GPU_IDLE: Self = Self{bits: nvmlClocksThrottleReasonGpuIdle as u64,}
Nothing is running on the GPU.
This limiter may be removed in a future release.
sourcepub const APPLICATIONS_CLOCKS_SETTING: Self = Self{bits: nvmlClocksThrottleReasonApplicationsClocksSetting as u64,}
pub const APPLICATIONS_CLOCKS_SETTING: Self = Self{bits: nvmlClocksThrottleReasonApplicationsClocksSetting as u64,}
GPU clocks are limited by the current applications clocks setting.
pub const USER_DEFINED_CLOCKS: Self = Self{bits: nvmlClocksThrottleReasonUserDefinedClocks as u64,}
Renamed to APPLICATIONS_CLOCKS_SETTING.
sourcepub const SW_POWER_CAP: Self = Self{bits: nvmlClocksThrottleReasonSwPowerCap as u64,}
pub const SW_POWER_CAP: Self = Self{bits: nvmlClocksThrottleReasonSwPowerCap as u64,}
Software power scaling algorithm is reducing clocks.
sourcepub const HW_SLOWDOWN: Self = Self{bits: nvmlClocksThrottleReasonHwSlowdown as u64,}
pub const HW_SLOWDOWN: Self = Self{bits: nvmlClocksThrottleReasonHwSlowdown as u64,}
Hardware slowdown (reducing the core clocks by a factor of 2 or more) is engaged.
This is an indicator of:
- Temperature being too high
- External Power Brake Asseration being triggered (e.g. by the system power supply)
- Power draw being too high and Fast Trigger protection reducing the clocks
This may also be reported during powerstate or clock change, behavior that may be removed in a later release.
sourcepub const SYNC_BOOST: Self = Self{bits: nvmlClocksThrottleReasonSyncBoost as u64,}
pub const SYNC_BOOST: Self = Self{bits: nvmlClocksThrottleReasonSyncBoost as u64,}
This GPU is being throttled by another GPU in its sync boost group.
Sync boost groups can be used to maximize performance per watt. All GPUs in a sync boost group will boost to the minimum possible clocks across the entire group. Look at the throttle reasons for other GPUs in the system to find out why this GPU is being held at lower clocks.
sourcepub const SW_THERMAL_SLOWDOWN: Self = Self{bits: nvmlClocksThrottleReasonSwThermalSlowdown as u64,}
pub const SW_THERMAL_SLOWDOWN: Self = Self{bits: nvmlClocksThrottleReasonSwThermalSlowdown as u64,}
Software thermal slowdown.
This is an indicator of one or more of the following:
- The current GPU temperature is above the max GPU operating temperature
- The current memory temperature is above the max memory operating temperature
sourcepub const HW_THERMAL_SLOWDOWN: Self = Self{bits: nvmlClocksThrottleReasonHwThermalSlowdown as u64,}
pub const HW_THERMAL_SLOWDOWN: Self = Self{bits: nvmlClocksThrottleReasonHwThermalSlowdown as u64,}
Hardware thermal slowdown is engaged, reducing core clocks by 2x or more.
This indicates that the temperature of the GPU is too high.
sourcepub const HW_POWER_BRAKE_SLOWDOWN: Self = Self{bits: nvmlClocksThrottleReasonHwPowerBrakeSlowdown as u64,}
pub const HW_POWER_BRAKE_SLOWDOWN: Self = Self{bits: nvmlClocksThrottleReasonHwPowerBrakeSlowdown as u64,}
Hardware power brake slowdown is engaged, reducing core clocks by 2x or more.
This indicates that an external power brake assertion is being triggered, such as by the system power supply.
sourcepub const DISPLAY_CLOCK_SETTING: Self = Self{bits: nvmlClocksThrottleReasonDisplayClockSetting as u64,}
pub const DISPLAY_CLOCK_SETTING: Self = Self{bits: nvmlClocksThrottleReasonDisplayClockSetting as u64,}
GPU clocks are limited by the current setting of display clocks.
sourcepub const NONE: Self = Self{bits: nvmlClocksThrottleReasonNone as u64,}
pub const NONE: Self = Self{bits: nvmlClocksThrottleReasonNone as u64,}
Clocks are as high as possible and are not being throttled.
sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.
sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from underlying bit representation, dropping any bits that do not correspond to flags.
sourcepub const unsafe fn from_bits_unchecked(bits: u64) -> Self
pub const unsafe fn from_bits_unchecked(bits: u64) -> Self
Convert from underlying bit representation, preserving all bits (even those not corresponding to a defined flag).
Safety
The caller of the bitflags! macro can chose to allow or
disallow extra bits for their bitflags type.
The caller of from_bits_unchecked() has to ensure that
all bits correspond to a defined flag or that extra bits
are valid for this bitflags type.
sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Returns true if there are flags common to both self and other.
sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Returns true if all of the flags in other are contained within self.
sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Inserts or removes the specified flags depending on the passed value.
sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
Returns the intersection between the flags in self and
other.
Specifically, the returned set contains only the flags which are
present in both self and other.
This is equivalent to using the & operator (e.g.
ops::BitAnd), as in flags & other.
sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
Returns the union of between the flags in self and other.
Specifically, the returned set contains all flags which are
present in either self or other, including any which are
present in both (see Self::symmetric_difference if that
is undesirable).
This is equivalent to using the | operator (e.g.
ops::BitOr), as in flags | other.
sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
Returns the difference between the flags in self and other.
Specifically, the returned set contains all flags present in
self, except for the ones present in other.
It is also conceptually equivalent to the “bit-clear” operation:
flags & !other (and this syntax is also supported).
This is equivalent to using the - operator (e.g.
ops::Sub), as in flags - other.
sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
Returns the symmetric difference between the flags
in self and other.
Specifically, the returned set contains the flags present which
are present in self or other, but that are not present in
both. Equivalently, it contains the flags present in exactly
one of the sets self and other.
This is equivalent to using the ^ operator (e.g.
ops::BitXor), as in flags ^ other.
sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
Returns the complement of this set of flags.
Specifically, the returned set contains all the flags which are
not set in self, but which are allowed for this type.
Alternatively, it can be thought of as the set difference
between Self::all() and self (e.g. Self::all() - self)
This is equivalent to using the ! operator (e.g.
ops::Not), as in !flags.