Enum nvml_wrapper::enum_wrappers::device::Api
source · [−]pub enum Api {
ApplicationClocks,
AutoBoostedClocks,
}Expand description
API types that allow changes to default permission restrictions.
Variants
ApplicationClocks
APIs that change application clocks.
Applicable methods on Device: .set_applications_clocks(),
.reset_applications_clocks()
AutoBoostedClocks
APIs that enable/disable auto boosted clocks.
Applicable methods on Device: .set_auto_boosted_clocks()
Implementations
sourceimpl Api
impl Api
sourcepub fn as_c(&self) -> nvmlRestrictedAPI_enum
pub fn as_c(&self) -> nvmlRestrictedAPI_enum
Returns the C enum variant equivalent for the given Rust enum variant