Enum nvml_wrapper::enum_wrappers::device::ClockId
source · [−]pub enum ClockId {
Current,
TargetAppClock,
DefaultAppClock,
CustomerMaxBoost,
}Expand description
These are used in combo with Clock to specify a single clock value.
Variants
Current
Current actual clock value.
TargetAppClock
Target application clock.
DefaultAppClock
Default application clock target.
CustomerMaxBoost
OEM-defined maximum clock rate.
Implementations
sourceimpl ClockId
impl ClockId
sourcepub fn as_c(&self) -> nvmlClockId_enum
pub fn as_c(&self) -> nvmlClockId_enum
Returns the C enum variant equivalent for the given Rust enum variant