pub enum EccCounter {
    Volatile,
    Aggregate,
}
ECC counter types.

Note: Volatile counts are reset each time the driver loads. On Windows this is once per boot. On Linux this can be more frequent; the driver unloads when no active clients exist. If persistence mode is enabled or there is always a driver client active (such as X11), then Linux also sees per-boot behavior. If not, volatile counts are reset each time a compute app is run.

Variants

Volatile

Volatile counts are reset each time the driver loads.

Aggregate

Aggregate counts persist across reboots (i.e. for the lifetime of the device).

Implementations

Returns the C enum variant equivalent for the given Rust enum variant