pub enum EncoderType {
H264,
HEVC,
}Expand description
Represents encoder types that capacity can be queried for.
Variants
Implementations
Sourceimpl EncoderType
impl EncoderType
Sourcepub fn as_c(&self) -> nvmlEncoderQueryType_enum
pub fn as_c(&self) -> nvmlEncoderQueryType_enum
Returns the C enum variant equivalent for the given Rust enum variant