Enum nvml_wrapper::enum_wrappers::device::OperationMode
source · [−]pub enum OperationMode {
AllOn,
Compute,
LowDP,
}Expand description
GPU operation mode.
Allows for the reduction of power usage and optimization of GPU throughput by disabling GPU features. Each mode is designed to meet specific needs.
Variants
AllOn
Everything is enabled and running at full speed.
Compute
Designed for running only compute tasks; disables graphics operations.
LowDP
Designed for running graphics applications that don’t require high bandwidth double precision.
Implementations
sourceimpl OperationMode
impl OperationMode
sourcepub fn as_c(&self) -> nvmlGom_enum
pub fn as_c(&self) -> nvmlGom_enum
Returns the C enum variant equivalent for the given Rust enum variant