pub enum PerformancePolicy {
Power,
Thermal,
SyncBoost,
BoardLimit,
LowUtilization,
Reliability,
TotalAppClocks,
TotalBaseClocks,
}Expand description
Types of performance policy for which violation times can be queried.
Variants
Power
Thermal
SyncBoost
BoardLimit
LowUtilization
Reliability
Board reliability limit.
TotalAppClocks
Total time the GPU was limited by any of the above.
TotalBaseClocks
Total time the GPU was held below base clocks.
Implementations
sourceimpl PerformancePolicy
impl PerformancePolicy
sourcepub fn as_c(&self) -> nvmlPerfPolicyType_enum
pub fn as_c(&self) -> nvmlPerfPolicyType_enum
Returns the C enum variant equivalent for the given Rust enum variant