pub enum Sampling {
    Power,
    GpuUtilization,
    MemoryUtilization,
    EncoderUtilization,
    DecoderUtilization,
    ProcessorClock,
    MemoryClock,
}
Possible types of sampling events.

Variants

Power

Total power drawn by GPU.

GpuUtilization

Percent of time during which one or more kernels was executing on the GPU.

MemoryUtilization

Percent of time during which global (device) memory was being read or written.

EncoderUtilization

Percent of time during which NVENC remains busy.

DecoderUtilization

Percent of time during which NVDEC remains busy.

ProcessorClock

Processor clock samples.

MemoryClock

Memory clock samples.

Implementations

Returns the C enum variant equivalent for the given Rust enum variant