pub enum BusType {
Unknown,
Pci,
Pcie,
Fpci,
Agp,
}Expand description
Returned by crate::Device::bus_type().
Variants
Unknown
Unknown bus type.
Pci
PCI (Peripheral Component Interconnect) bus type.
Pcie
PCIE (Peripheral Component Interconnect Express) bus type.
This is the most common bus type.
Fpci
FPCI (Fast Peripheral Component Interconnect) bus type.
Agp
AGP (Accelerated Graphics Port) bus type.
This is old and was dropped in favor of PCIE.
Implementations
sourceimpl BusType
impl BusType
sourcepub fn as_c(&self) -> nvmlBusType_t
pub fn as_c(&self) -> nvmlBusType_t
Returns the C constant equivalent for the given Rust enum variant.