Enum nvml_wrapper::enums::device::DeviceArchitecture
source · [−]pub enum DeviceArchitecture {
Kepler,
Maxwell,
Pascal,
Volta,
Turing,
Ampere,
Unknown,
}Expand description
Returned by crate::Device::architecture().
This is the simplified chip architecture of the device.
Variants
Kepler
Maxwell
Pascal
Volta
Turing
Ampere
Unknown
Unknown device architecture (most likely something newer).
Implementations
sourceimpl DeviceArchitecture
impl DeviceArchitecture
sourcepub fn as_c(&self) -> nvmlDeviceArchitecture_t
pub fn as_c(&self) -> nvmlDeviceArchitecture_t
Returns the C constant equivalent for the given Rust enum variant.