pub enum PcieLinkMaxSpeed {
    Invalid,
    MegabytesPerSecond2500,
    MegabytesPerSecond5000,
    MegabytesPerSecond8000,
    MegabytesPerSecond16000,
    MegabytesPerSecond32000,
}
Returned by crate::Device::pcie_link_max_speed().

Note, the NVML header says these are all MBPS (Megabytes Per Second) but they don’t line up with the throughput numbers on this page: https://en.wikipedia.org/wiki/PCI_Express

They do line up with the “transfer rate per lane” numbers, though.

Variants

Invalid

MegabytesPerSecond2500

MegabytesPerSecond5000

MegabytesPerSecond8000

MegabytesPerSecond16000

MegabytesPerSecond32000

Implementations

Returns the C constant equivalent for the given Rust enum variant.