Module error

Module error 

Structs

NvmlErrorWithSource
An NvmlError with an optionally present source error for chaining errors

Enums

Bits
NvmlError

Functions

nvml_sym
Helper to map a &libloading::Error into an NvmlError
nvml_try
Converts an nvmlReturn_t type into a Result<(), NvmlError>.
nvml_try_count
Converts an nvmlReturn_t type into a Result<(), NvmlError>, allowing for the call to return the value nvmlReturn_enum_NVML_ERROR_INSUFFICIENT_SIZE which is a common return value when using an in/out parameter that provides the size of a buffer needed to complete that call