nvml_try_count

Function nvml_try_count 

pub fn nvml_try_count(code: nvmlReturn_t) -> Result<(), NvmlError>
Converts an nvmlReturn_t type into a Result<(), NvmlError>, allowing for the call to return the value nvmlReturn_enum_NVML_ERROR_INSUFFICIENT_SIZE which is a common return value when using an in/out parameter that provides the size of a buffer needed to complete that call