Struct nvml_wrapper::error::NvmlErrorWithSource
source · [−]Expand description
An NvmlError with an optionally present source error for chaining errors
Fields
error: NvmlErrorsource: Option<NvmlError>Trait Implementations
sourceimpl Debug for NvmlErrorWithSource
impl Debug for NvmlErrorWithSource
sourceimpl Display for NvmlErrorWithSource
impl Display for NvmlErrorWithSource
sourceimpl Error for NvmlErrorWithSource
impl Error for NvmlErrorWithSource
sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
The lower-level source of this error, if any. Read more
sourcefn backtrace(&self) -> Option<&Backtrace>
fn backtrace(&self) -> Option<&Backtrace>
🔬 This is a nightly-only experimental API. (
backtrace)Returns a stack backtrace, if available, of where this error occurred. Read more
1.0.0 · sourcefn description(&self) -> &str
fn description(&self) -> &str
👎 Deprecated since 1.42.0:
use the Display impl or to_string()