pub struct NvmlBuilder<'a> { /* private fields */ }
A builder struct that provides further flexibility in how NVML is initialized.

Examples

Initialize NVML with a non-default name for the shared object file:

use nvml_wrapper::Nvml;
use std::ffi::OsStr;

let init_result = Nvml::builder().lib_path(OsStr::new("libnvidia-ml-other-name.so")).init();

Initialize NVML with a non-default path to the shared object file:

use nvml_wrapper::Nvml;
use std::ffi::OsStr;

let init_result = Nvml::builder().lib_path(OsStr::new("/some/path/to/libnvidia-ml.so")).init();

Implementations

Set the path to the NVML lib file.

See libloading’s docs for details about how this lib path is handled.

Set the InitFlags to initialize NVML with.

Perform initialization.