pub struct AccountingStats {
    pub gpu_utilization: Option<u32>,
    pub is_running: bool,
    pub max_memory_usage: Option<u64>,
    pub memory_utilization: Option<u32>,
    pub start_time: u64,
    pub time: u64,
}
Accounting statistics for a process.

There is a field: unsigned int reserved[5] present on the C struct that this wraps that NVIDIA says is “reserved for future use.” If it ever gets used in the future, an equivalent wrapping field will have to be added to this struct.

Fields

gpu_utilization: Option<u32>

Percent of time over the process’s lifetime during which one or more kernels was executing on the GPU. This is just like what is returned by Device.utilization_rates() except it is for the lifetime of a process (not just the last sample period).

It will be None if Device.utilization_rates() is not supported.

is_running: bool

Whether the process is running.

max_memory_usage: Option<u64>

Max total memory in bytes that was ever allocated by the process.

It will be None if ProcessInfo.used_gpu_memory is not supported.

memory_utilization: Option<u32>

Percent of time over the process’s lifetime during which global (device) memory was being read from or written to.

It will be None if Device.utilization_rates() is not supported.

start_time: u64

CPU timestamp in usec representing the start time for the process.

time: u64

Amount of time in ms during which the compute context was active. This will be zero if the process is not terminated.