pub struct BridgeChipHierarchy {
    pub chips_hierarchy: Vec<BridgeChipInfo>,
    pub chip_count: u8,
}
This struct stores the complete hierarchy of the bridge chip within the board.

The immediate bridge is stored at index 0 of chips_hierarchy. The parent to the immediate bridge is at index 1, and so forth.

Fields

chips_hierarchy: Vec<BridgeChipInfo>

Hierarchy of bridge chips on the board.

chip_count: u8

Number of bridge chips on the board.