pub struct FbcStats {
    pub sessions_count: u32,
    pub average_fps: u32,
    pub average_latency: u32,
}
Holds global frame buffer capture session statistics.

Fields

sessions_count: u32

The total number of sessions

average_fps: u32

Moving average of new frames captured per second for all capture sessions

average_latency: u32

Moving average of new frame capture latency in microseconds for all capture sessions