pub struct PciInfo {
    pub bus: u32,
    pub bus_id: String,
    pub device: u32,
    pub domain: u32,
    pub pci_device_id: u32,
    pub pci_sub_system_id: Option<u32>,
}
PCI information about a GPU device.

Fields

bus: u32

The bus on which the device resides, 0 to 0xff.

bus_id: String

The PCI identifier.

device: u32

The device’s ID on the bus, 0 to 31.

domain: u32

The PCI domain on which the device’s bus resides, 0 to 0xffff.

pci_device_id: u32

The combined 16-bit device ID and 16-bit vendor ID.

pci_sub_system_id: Option<u32>

The 32-bit Sub System Device ID.

Will always be None if this PciInfo was obtained from NvLink.remote_pci_info(). NVIDIA says that the C field that this corresponds to “is not filled … and is indeterminate” when being returned from that specific call.

Will be Some in all other cases.

Implementations

Try to create this struct from its C equivalent.

Passing false for sub_sys_id_present will set the pci_sub_system_id field to None. See the field docs for more.

Errors
  • Utf8Error, if the string obtained from the C function is not valid Utf8