Struct nvml_wrapper::struct_wrappers::device::ProcessInfo
source · [−]pub struct ProcessInfo {
pub pid: u32,
pub used_gpu_memory: UsedGpuMemory,
pub gpu_instance_id: Option<u32>,
pub compute_instance_id: Option<u32>,
}Expand description
Information about compute processes running on the GPU.
Fields
pid: u32used_gpu_memory: UsedGpuMemoryAmount of used GPU memory in bytes.
gpu_instance_id: Option<u32>The ID of the GPU instance this process is running on, if applicable.
MIG (Multi-Instance GPU) must be enabled on the device for this field to be set.
compute_instance_id: Option<u32>The ID of the compute instance this process is running on, if applicable.
MIG (Multi-Instance GPU) must be enabled on the device for this field to be set.