pub struct Utilization {
    pub gpu: u32,
    pub memory: u32,
}
Utilization information for a device. Each sample period may be between 1 second and 1/6 second, depending on the product being queried.

Fields

gpu: u32

Percent of time over the past sample period during which one or more kernels was executing on the GPU.

memory: u32

Percent of time over the past sample period during which global (device) memory was being read or written to.