VgpuSchedulerSetParams

Struct VgpuSchedulerSetParams 

pub struct VgpuSchedulerSetParams {
    pub avg_factor: Option<u32>,
    pub frequency_or_timeslice: u32,
}

Fields

avg_factor: Option<u32>

Average factor in compensating the timeslice for Adaptive Round Robin mode

frequency_or_timeslice: u32

Frequency for Adaptative Mode (when avg_factor is set)/timeslice in ns for each software run list as configured, or the default value otherwise

Implementations