Struct nvml_wrapper::structs::device::AutoBoostClocksEnabledInfo
source · [−]Expand description
Returned from Device.auto_boosted_clocks_enabled()
Fields
is_enabled: boolCurrent state of auto boosted clocks for the Device
is_enabled_default: boolDefault auto boosted clocks behavior for the Device
The GPU will revert to this default when no applications are using the GPU.