Struct nvml_wrapper::structs::device::RetiredPage
source · [−]Expand description
Returned from Device.retired_pages()
Fields
address: u64The hardware address of the page that was retired.
Note that this does not match the virtual address used in CUDA but does match the address information in XID 63.
timestamp: u64The retirement timestamp.