Enum nvml_wrapper::enum_wrappers::device::ComputeMode
source · [−]pub enum ComputeMode {
Default,
ExclusiveThread,
Prohibited,
ExclusiveProcess,
}Expand description
ExclusiveProcess was added in CUDA 4.0. Earlier CUDA versions supported a
single exclusive mode, which is equivalent to ExclusiveThread in CUDA 4.0
and beyond.
Variants
Default
Multiple contexts per device.
ExclusiveThread
SUPPORT REMOVED
Only one context per device, usable from one thread at a time. NOT SUPPORTED
Prohibited
No contexts per device.
ExclusiveProcess
Only one context per device, usable from multiple threads at a time.
Implementations
sourceimpl ComputeMode
impl ComputeMode
sourcepub fn as_c(&self) -> nvmlComputeMode_enum
pub fn as_c(&self) -> nvmlComputeMode_enum
Returns the C enum variant equivalent for the given Rust enum variant