Enum nvml_wrapper::enum_wrappers::device::EncoderType
source · [−]pub enum EncoderType {
H264,
HEVC,
}Expand description
Represents encoder types that capacity can be queried for.
Variants
H264
HEVC
Implementations
sourceimpl EncoderType
impl EncoderType
sourcepub fn as_c(&self) -> nvmlEncoderQueryType_enum
pub fn as_c(&self) -> nvmlEncoderQueryType_enum
Returns the C enum variant equivalent for the given Rust enum variant