Enum nvml_wrapper::enum_wrappers::device::Sampling
source · [−]pub enum Sampling {
Power,
GpuUtilization,
MemoryUtilization,
EncoderUtilization,
DecoderUtilization,
ProcessorClock,
MemoryClock,
}Expand description
Possible types of sampling events.
Variants
Power
Total power drawn by GPU.
GpuUtilization
Percent of time during which one or more kernels was executing on the GPU.
MemoryUtilization
Percent of time during which global (device) memory was being read or written.
EncoderUtilization
Percent of time during which NVENC remains busy.
DecoderUtilization
Percent of time during which NVDEC remains busy.
ProcessorClock
Processor clock samples.
MemoryClock
Memory clock samples.
Implementations
sourceimpl Sampling
impl Sampling
sourcepub fn as_c(&self) -> nvmlSamplingType_enum
pub fn as_c(&self) -> nvmlSamplingType_enum
Returns the C enum variant equivalent for the given Rust enum variant