Enum nvml_wrapper::enum_wrappers::device::TopologyLevel
source · [−]pub enum TopologyLevel {
Internal,
Single,
Multiple,
HostBridge,
Node,
System,
}Expand description
Level relationships within a system between two GPUs.
Variants
Internal
e.g. Tesla K80.
Single
All devices that only need traverse a single PCIe switch.
Multiple
All devices that need not traverse a host bridge.
HostBridge
All devices that are connected to the same host bridge.
Node
All devices that are connected to the same NUMA node but possibly multiple host bridges.
This was Cpu in previous versions of NVML.
System
All devices in the system
Implementations
sourceimpl TopologyLevel
impl TopologyLevel
sourcepub fn as_c(&self) -> nvmlGpuLevel_enum
pub fn as_c(&self) -> nvmlGpuLevel_enum
Returns the C enum variant equivalent for the given Rust enum variant