Enum nvml_wrapper::enums::device::GpuLockedClocksSetting
source · [−]pub enum GpuLockedClocksSetting {
Numeric {
min_clock_mhz: u32,
max_clock_mhz: u32,
},
Symbolic {
lower_bound: ClockLimitId,
upper_bound: ClockLimitId,
},
}Expand description
Represents different types of sample values.
Variants
Numeric
Numeric setting that allows you to explicitly define minimum and maximum clock frequencies.
Symbolic
Symbolic setting that allows you to define lower and upper bounds for clock speed with various possibilities.
Not all combinations of lower_bound and upper_bound are valid.
Please see the docs for nvmlDeviceSetGpuLockedClocks in nvml.h to
learn more.
Implementations