pub enum NvmlError {
Show 33 variants Utf8Error(Utf8Error), NulError(NulError), LibloadingError(Error), FailedToLoadSymbol(String), StringTooLong { max_len: usize, actual_len: usize, }, IncorrectBits(Bits), UnexpectedVariant(u32), SetReleaseFailed, GetPciInfoFailed, PciInfoToCFailed, Uninitialized, InvalidArg, NotSupported, NoPermission, AlreadyInitialized, NotFound, InsufficientSize(Option<usize>), InsufficientPower, DriverNotLoaded, Timeout, IrqIssue, LibraryNotFound, FunctionNotFound, CorruptedInfoROM, GpuLost, ResetRequired, OperatingSystem, LibRmVersionMismatch, InUse, InsufficientMemory, NoData, VgpuEccNotSupported, Unknown,
}

Variants

Utf8Error(Utf8Error)

NulError(NulError)

LibloadingError(Error)

FailedToLoadSymbol(String)

A function symbol failed to load.

This variant is constructed with a textual description of a libloading::Error. The error variant itself can’t be provided because we’re unable to take ownership of the error when attempting to use a symbol, and libloading::Error doesn’t impl Clone.

StringTooLong

Fields

max_len: usize
actual_len: usize

IncorrectBits(Bits)

UnexpectedVariant(u32)

An unexpected enum variant was encountered.

This error is specific to this Rust wrapper. It is used to represent the possibility that an enum variant that is not defined within the Rust bindings can be returned from a C call.

The single field contains the value that could not be mapped to a defined enum variant.

See this issue.

SetReleaseFailed

GetPciInfoFailed

PciInfoToCFailed

Uninitialized

InvalidArg

NotSupported

NoPermission

AlreadyInitialized

👎 Deprecated:

deprecated in NVML (multiple initializations now allowed via refcounting)

NotFound

InsufficientSize(Option<usize>)

An input argument is not large enough.

The single field is the size required for a successful call (if Some) and None if unknown.

InsufficientPower

DriverNotLoaded

Timeout

IrqIssue

LibraryNotFound

FunctionNotFound

CorruptedInfoROM

GpuLost

ResetRequired

OperatingSystem

LibRmVersionMismatch

InUse

InsufficientMemory

NoData

VgpuEccNotSupported

Unknown