Enum nvml_wrapper::high_level::event_loop::Event
source · [−]pub enum Event<'nvml> {
ClockChange(Device<'nvml>),
CriticalXidError(Device<'nvml>, XidError),
DoubleBitEccError(Device<'nvml>),
PowerStateChange(Device<'nvml>),
SingleBitEccError(Device<'nvml>),
Unknown,
}Expand description
Represents the event types that an EventLoop can gather for you.
These are analagous to the constants in bitmasks::event.
Checking to see if the Device within an Event is the same physical device as
another Device that you have on hand can be accomplished via Device.uuid().
Variants
ClockChange(Device<'nvml>)
CriticalXidError(Device<'nvml>, XidError)
DoubleBitEccError(Device<'nvml>)
PowerStateChange(Device<'nvml>)
SingleBitEccError(Device<'nvml>)
Unknown
Returned if none of the other Events are contained in the EventData
the EventLoop processes.