Struct nvml_wrapper::struct_wrappers::device::FbcSessionInfo
source · [−]pub struct FbcSessionInfo {
pub session_id: u32,
pub pid: u32,
pub vgpu_instance: Option<u32>,
pub display_ordinal: u32,
pub session_type: FbcSessionType,
pub session_flags: FbcFlags,
pub hres_max: u32,
pub vres_max: u32,
pub hres: u32,
pub vres: u32,
pub average_fps: u32,
pub average_latency: u32,
}Expand description
Information about a frame buffer capture session.
Fields
session_id: u32Unique session ID
pid: u32The ID of the process that owns this session
vgpu_instance: Option<u32>The ID of the vGPU instance that owns this session (if applicable).
display_ordinal: u32The identifier of the display this session is running on
session_type: FbcSessionTypeThe type of this session
session_flags: FbcFlagsVarious flags with info
hres_max: u32The maximum horizontal resolution supported by this session
vres_max: u32The maximum vertical resolution supported by this session
hres: u32The horizontal resolution requested by the caller in the capture call
vres: u32The vertical resolution requested by the caller in the capture call
average_fps: u32Moving average of new frames captured per second for this session
average_latency: u32Moving average of new frame capture latency in microseconds for this session