Struct nvml_wrapper::struct_wrappers::device::FbcStats
source · [−]Expand description
Holds global frame buffer capture session statistics.
Fields
sessions_count: u32The total number of sessions
average_fps: u32Moving average of new frames captured per second for all capture sessions
average_latency: u32Moving average of new frame capture latency in microseconds for all capture sessions