Struct nvml_wrapper::struct_wrappers::device::FieldValueSample
source · [−]pub struct FieldValueSample {
pub field: FieldId,
pub timestamp: i64,
pub latency: i64,
pub value: Result<SampleValue, NvmlError>,
}Expand description
Struct that stores information returned from Device.field_values_for().
Fields
field: FieldIdThe field that this sample is for.
timestamp: i64This sample’s CPU timestamp in μs (Unix time).
latency: i64How long this field value took to update within NVML, in μs.
This value may be averaged across several fields serviced by the same driver call.
value: Result<SampleValue, NvmlError>The value of this sample.
Will be an error if retrieving this specific value failed.