Struct nvml_wrapper::struct_wrappers::device::Utilization
source · [−]Expand description
Utilization information for a device. Each sample period may be between 1 second and 1/6 second, depending on the product being queried.
Fields
gpu: u32Percent of time over the past sample period during which one or more kernels was executing on the GPU.
memory: u32Percent of time over the past sample period during which global (device) memory was being read or written to.